@@ -3,9 +3,11 @@ import json
 import math
 import os
 import re
-import yaml
 
 import decorator
+import yaml
+from zuper_commons.text import indent
+from zuper_commons.types import ZValueError
 
 from . import logger
 from .exceptions import InvalidConfiguration
@@ -97,11 +99,12 @@ def wrap_config_reader2(f, cls, data: dict, *args, **kwargs):
     """ Decorator for a function that takes a (clsname, dict) """
     # def f2(x, *args, **kwargs):
     if not isinstance(data, dict):
-        msg = "Expected dict, got %s" % data.__repr__()
-        raise ValueError(msg)
+        msg = "Expected dict"
+        raise ZValueError(msg, data=data)
 
     def write(d: dict):
         assert isinstance(d, dict)
+        # noinspection PyBroadException
         try:
             return json.dumps(d, indent=4)
         except:
@@ -128,17 +131,16 @@ def wrap_config_reader2(f, cls, data: dict, *args, **kwargs):
         msg += "\n\n" + indent(write(data), "  > ") + "\n"
         # raise_wrapped(InvalidConfiguration, e, msg, compact=False)
         raise InvalidConfiguration(msg) from e
-
-    if data2:
-        msg = "Unused fields %s " % list(data2)
-        msg += "\n\n" + indent(write(data), "  > ")
-        raise InvalidConfiguration(msg)
+    #
+    # if data2:
+    #     msg = "Unused fields %s " % list(data2)
+    #     msg += "\n\n" + indent(write(data), "  > ")
+    #     raise InvalidConfiguration(msg)
 
     return res
 
 
 def safe_yaml_dump(x, **args):
-
     s = yaml.safe_dump(x, encoding="utf-8", indent=4, allow_unicode=True, **args)
     return s
 
@@ -181,25 +183,26 @@ def friendly_size2(b):
     return "%.2f GB" % gbs
 
 
-def indent(s, prefix: str, first=None):
-    s = str(s)
-
-    lines = s.split("\n")
-    if not lines:
-        return ""
-
-    if first is None:
-        first = prefix
-
-    m = max(len(prefix), len(first))
-
-    prefix = " " * (m - len(prefix)) + prefix
-    first = " " * (m - len(first)) + first
-
-    # differnet first prefix
-    res = ["%s%s" % (prefix, line.rstrip()) for line in lines]
-    res[0] = "%s%s" % (first, lines[0].rstrip())
-    return "\n".join(res)
+#
+# def indent(s, prefix: str, first=None):
+#     s = str(s)
+#
+#     lines = s.split("\n")
+#     if not lines:
+#         return ""
+#
+#     if first is None:
+#         first = prefix
+#
+#     m = max(len(prefix), len(first))
+#
+#     prefix = " " * (m - len(prefix)) + prefix
+#     first = " " * (m - len(first)) + first
+#
+#     # differnet first prefix
+#     res = ["%s%s" % (prefix, line.rstrip()) for line in lines]
+#     res[0] = "%s%s" % (first, lines[0].rstrip())
+#     return "\n".join(res)
 
 
 #
@@ -242,20 +245,20 @@ def indent(s, prefix: str, first=None):
 #
 #     return etype(s)
 
-
-def check_isinstance(ob, expected, **kwargs):
-    if not isinstance(ob, expected):
-        kwargs["object"] = ob
-        raise_type_mismatch(ob, expected, **kwargs)
-
-
-def raise_type_mismatch(ob, expected, **kwargs):
-    """ Raises an exception concerning ob having the wrong type. """
-    e = "Object not of expected type:"
-    e += "\n  expected: %s" % str(expected)
-    e += "\n  obtained: %s" % str(type(ob))
-    # e += '\n' + indent(format_obs(kwargs), ' ')
-    raise ValueError(e)
+#
+# def check_isinstance(ob, expected, **kwargs):
+#     if not isinstance(ob, expected):
+#         kwargs["object"] = ob
+#         raise_type_mismatch(ob, expected, **kwargs)
+#
+#
+# def raise_type_mismatch(ob, expected, **kwargs):
+#     """ Raises an exception concerning ob having the wrong type. """
+#     e = "Object not of expected type:"
+#     e += "\n  expected: %s" % str(expected)
+#     e += "\n  obtained: %s" % str(type(ob))
+#     # e += '\n' + indent(format_obs(kwargs), ' ')
+#     raise ValueError(e)
 
 
 def tag_from_date(d):
